@@ -1,6 +1,6 @@
 use super::{count_android_filter, should_filter_android, Distrib, Selector, SelectorResult};
 use crate::{
-    data::caniuse::{get_browser_stat, CANIUSE_LITE_BROWSERS},
+    data::caniuse::{get_browser_stat, CANIUSE_BROWSERS},
     error::Error,
     opts::Opts,
 };
@@ -23,7 +23,7 @@ impl Selector for LastNBrowsersSelector {
             None => return Ok(None),
         };
 
-        let versions = CANIUSE_LITE_BROWSERS
+        let versions = CANIUSE_BROWSERS
             .keys()
             .filter_map(|name| get_browser_stat(name, opts.mobile_to_desktop))
             .map(|(name, stat)| {
@@ -33,11 +33,12 @@ impl Selector for LastNBrowsersSelector {
                     count
                 };
 
-                stat.released
+                stat.version_list
                     .iter()
+                    .filter(|version| version.release_date.is_some())
                     .rev()
                     .take(count)
-                    .map(move |version| Distrib::new(name, version))
+                    .map(move |version| Distrib::new(name, &*version.version))
             })
             .flatten()
             .collect();
@@ -45,3 +46,18 @@ impl Selector for LastNBrowsersSelector {
         Ok(Some(versions))
     }
 }
+
+#[cfg(test)]
+mod tests {
+    use super::*;
+    use crate::test::run_compare;
+    use test_case::test_case;
+
+    #[test_case("last 2 versions"; "basic")]
+    #[test_case("last 31 versions"; "android")]
+    #[test_case("last 1 version"; "support pluralization")]
+    #[test_case("Last 02 Versions"; "case insensitive")]
+    fn default_options(query: &str) {
+        run_compare(query, &Opts::new());
+    }
+}
