@@ -32,9 +32,23 @@ impl Selector for LastNElectronMajorSelector {
             .iter()
             .filter(|(electron_version, _)| electron_version >= minimum)
             .rev()
-            .map(|(_, chrome_version)| Distrib::new("chrome", chrome_version))
+            .map(|(_, chromium_version)| Distrib::new("chrome", chromium_version))
             .collect();
 
         Ok(Some(versions))
     }
 }
+
+#[cfg(test)]
+mod tests {
+    use super::*;
+    use crate::test::run_compare;
+    use test_case::test_case;
+
+    #[test_case("last 2 electron major versions"; "basic")]
+    #[test_case("last 2 Electron major versions"; "case insensitive")]
+    #[test_case("last 2 electron major version"; "support pluralization")]
+    fn valid(query: &str) {
+        run_compare(query, &Opts::new());
+    }
+}
