@@ -30,12 +30,31 @@ impl Selector for LastNXBrowsersSelector {
         };
 
         let versions = stat
-            .released
+            .version_list
             .iter()
+            .filter(|version| version.release_date.is_some())
             .rev()
             .take(count)
-            .map(|version| Distrib::new(name, version))
+            .map(|version| Distrib::new(name, &*version.version))
             .collect();
         Ok(Some(versions))
     }
 }
+
+#[cfg(test)]
+mod tests {
+    use super::*;
+    use crate::test::run_compare;
+    use test_case::test_case;
+
+    #[test_case("last 2 ie versions"; "basic")]
+    #[test_case("last 2 safari versions"; "do not include unreleased versions")]
+    #[test_case("last 1 ie version"; "support pluralization")]
+    #[test_case("last 01 Explorer version"; "alias")]
+    #[test_case("Last 01 IE Version"; "case insensitive")]
+    #[test_case("last 4 android versions"; "android 1")]
+    #[test_case("last 31 android versions"; "android 2")]
+    fn default_options(query: &str) {
+        run_compare(query, &Opts::new());
+    }
+}
