@@ -1,6 +1,6 @@
 use super::{Distrib, Selector, SelectorResult};
 use crate::{
-    data::caniuse::{get_browser_stat, CANIUSE_LITE_BROWSERS},
+    data::caniuse::{get_browser_stat, CANIUSE_BROWSERS},
     opts::Opts,
 };
 use once_cell::sync::Lazy;
@@ -18,14 +18,14 @@ pub(super) struct UnreleasedBrowsersSelector;
 impl Selector for UnreleasedBrowsersSelector {
     fn select<'a>(&self, text: &'a str, opts: &Opts) -> SelectorResult {
         if REGEX.is_match(text) {
-            let versions = CANIUSE_LITE_BROWSERS
+            let versions = CANIUSE_BROWSERS
                 .keys()
                 .filter_map(|name| get_browser_stat(name, opts.mobile_to_desktop))
                 .map(|(name, stat)| {
-                    stat.versions
+                    stat.version_list
                         .iter()
-                        .filter(|version| !stat.released.contains(version))
-                        .map(|version| Distrib::new(name, version))
+                        .filter(|version| version.release_date.is_none())
+                        .map(|version| Distrib::new(name, &*version.version))
                 })
                 .flatten()
                 .collect();
@@ -35,3 +35,17 @@ impl Selector for UnreleasedBrowsersSelector {
         }
     }
 }
+
+#[cfg(test)]
+mod tests {
+    use super::*;
+    use crate::test::run_compare;
+    use test_case::test_case;
+
+    #[test_case("unreleased versions"; "basic")]
+    #[test_case("Unreleased Versions"; "case insensitive")]
+    #[test_case("unreleased        versions"; "more spaces")]
+    fn valid(query: &str) {
+        run_compare(query, &Opts::new());
+    }
+}
